@@ -286,7 +286,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         page_vbox.pack_start(box, False)
 
         # CSound_("Musical MIDI Accompaniment:")
-        for bin, label, bins in (
+        for binary, label, bins in (
             ("csound", _("CSound:"), osutils.find_csound_executables()),
             ("mma", "MMA:", osutils.find_mma_executables(
                 cfg.get_list("app/win32_ignore_drives"))),
@@ -299,11 +299,11 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             for p in bins:
                 liststore.append((p,))
             cbox_entry = gtk.ComboBoxEntry(liststore)
-            cbox_entry.child.set_text(self.get_string("programs/%(bin)s" % locals()))
-            def csound_changed_cb(widget, bin):
-                self.set_string('programs/%s' % bin, widget.child.get_text())
+            cbox_entry.child.set_text(self.get_string("programs/%(binary)s" % locals()))
+            def csound_changed_cb(widget, binary):
+                self.set_string('programs/%s' % binary, widget.child.get_text())
                 widget.warning.props.visible = not bool(
-                    osutils.find_progs((cfg.get_string('programs/%s' % bin),)))
+                    osutils.find_progs((cfg.get_string('programs/%s' % binary),)))
             cbox_entry.warning = gtk.Image()
             cbox_entry.warning.set_tooltip_text(_("Not found. Much of GNU Solfege will run fine without this program. You will get a message when the program is required, and the user manual will explain what you need it for."))
             cbox_entry.warning.set_from_stock(gtk.STOCK_DIALOG_WARNING,
@@ -313,8 +313,8 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                                       sizegroup, True, True)
             category_vbox.pack_start(box)
             cbox_entry.warning.props.no_show_all = True
-            csound_changed_cb(cbox_entry, bin)
-            cbox_entry.connect('changed', csound_changed_cb, bin)
+            csound_changed_cb(cbox_entry, binary)
+            cbox_entry.connect('changed', csound_changed_cb, binary)
     def create_gui_config(self):
         i_iter, page_vbox = self.new_page_box(None, _("Interface"))
 
@@ -393,7 +393,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                     is_unique = False
                     break
             if not is_unique:
-                gu.dialog_ok(_("The accelerator in use for the tone “%s”. You have to choose another key.") % solfege.mpd.MusicalPitch.new_from_notename(notename).get_user_notename(), parent=self, msgtype=gtk.MESSAGE_ERROR)
+                gu.dialog_ok(_(u"The accelerator in use for the tone “%s”. You have to choose another key.") % solfege.mpd.MusicalPitch.new_from_notename(notename).get_user_notename(), parent=self, msgtype=gtk.MESSAGE_ERROR)
                 return
             it = self.g_idtone_accels.get_iter(path)
             cfg.set_string('idtone/tone_%s_ak' % notenames[int(path)], unichr(accel_key))
@@ -449,7 +449,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                     is_unique = False
                     break
             if not is_unique:
-                gu.dialog_ok(_("The accelerator in use for “%s”. You have to choose another key.") % mpd.Interval.new_from_int(intervals.index(interval)).get_name(), parent=self, msgtype=gtk.MESSAGE_ERROR)
+                gu.dialog_ok(_(u"The accelerator in use for “%s”. You have to choose another key.") % mpd.Interval.new_from_int(intervals.index(interval)).get_name(), parent=self, msgtype=gtk.MESSAGE_ERROR)
                 return
             it = self.g_interval_accels.get_iter(path)
             cfg.set_string('interval_input/%s' % intervals[int(path)], unichr(accel_key))
@@ -815,7 +815,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             try:
                 soundcard.initialise_alsa_sequencer(self.m_gui_client_port)
             except solfege.soundcard.alsa_sequencer.alsaseq.SequencerError, e:
-                logging.debug("initialise_alsa_sequencer(%s) failed: %s" % (self.m_gui_client_port, str(e)))
+                logging.debug("initialise_alsa_sequencer(%s) failed: %s", self.m_gui_client_port, str(e))
                 solfege.app.display_sound_init_error_message(e)
                 return -1
         else: # no sound
