@@ -22,13 +22,11 @@ import logging
 import os
 import StringIO
 import subprocess
-import sys
-import time
-import weakref
 
-import gobject
 import gtk
 
+from solfege.esel import SearchView
+
 if __name__ == '__main__':
     from solfege import i18n
     i18n.setup(".", "C")
@@ -41,7 +39,6 @@ from solfege import filesystem
 from solfege import gu
 from solfege import frontpage as pd
 from solfege import lessonfile
-from solfege import lessonfilegui
 from solfege import osutils
 
 class LessonFilePreviewWidget(gtk.VBox):
@@ -90,7 +87,7 @@ class LessonFilePreviewWidget(gtk.VBox):
                     l = gtk.Label(u"-")
                     l.set_alignment(0.0, 0.5)
                     self.g_topic_box.pack_start(l, False)
-            except (lessonfile.InfoCache.FileNotFound, 
+            except (lessonfile.InfoCache.FileNotFound,
                     lessonfile.InfoCache.FileNotLessonfile), e:
                 self.g_title.set_text(u'')
                 self.g_module.set_text(u'')
@@ -113,6 +110,19 @@ class SelectLessonFileDialog(gtk.FileChooserDialog):
         self.connect('selection-changed', pv.update)
 
 
+class SelectLessonfileBySearchDialog(gtk.Dialog):
+    def __init__(self):
+        gtk.Dialog.__init__(self, buttons=(gtk.STOCK_CLOSE, gtk.RESPONSE_ACCEPT))
+        view = SearchView(_('Search for exercises. Each exercise you click will be added to the section of the front page.'),
+            fields=['link-with-filename-tooltip', 'module'])
+        view.on_link_clicked = self.on_link_clicked
+        self.vbox.pack_start(view)
+        self.show_all()
+    def on_link_clicked(self, widget, filename):
+        self.m_filename = filename
+        self.response(gtk.RESPONSE_OK)
+
+
 def editor_of(obj):
     """
     Return the toplevel page, the one that is a Editor object.
@@ -128,12 +138,15 @@ def parent_page(obj):
     """
     p = obj
     while True:
-        p = p.m_parent
+        try:
+            p = p.m_parent
+        except AttributeError:
+            return None
         if isinstance(p, Page):
             return p
         if p is None:
             return None
-    
+
 class Section(gtk.VBox):
     """
     A section consists of a heading and a list of links.
@@ -200,14 +213,16 @@ class Section(gtk.VBox):
         im.set_from_stock(gtk.STOCK_GO_DOWN, gtk.ICON_SIZE_MENU)
         self.g_move_down_btn = gtk.Button()
         self.g_move_down_btn.add(im)
-        self.g_move_down_btn.connect('clicked', self.on_move_down)
+        self.g_move_down_btn.connect('clicked',
+            self.m_parent.move_section_down, self)
         button_hbox.pack_start(self.g_move_down_btn, False)
         #
         im = gtk.Image()
         im.set_from_stock(gtk.STOCK_GO_UP, gtk.ICON_SIZE_MENU)
         self.g_move_up_btn = gtk.Button()
         self.g_move_up_btn.add(im)
-        self.g_move_up_btn.connect('clicked', self.on_move_up)
+        self.g_move_up_btn.connect('clicked',
+            self.m_parent.move_section_up, self)
         button_hbox.pack_start(self.g_move_up_btn, False)
         #
         im = gtk.Image()
@@ -233,10 +248,6 @@ class Section(gtk.VBox):
         # The button to click to add a new link
         hbox = gtk.HBox()
         self.pack_start(hbox)
-    def on_move_down(self, btn):
-        self.m_parent.move_section_down(self)
-    def on_move_up(self, btn):
-        self.m_parent.move_section_up(self)
     def on_edit_heading(self, btn):
         self.g_heading_entry.set_text(self.m_model.m_name)
         self.g_heading_entry.show()
@@ -271,10 +282,22 @@ class Section(gtk.VBox):
         item = gtk.MenuItem(_("Add link to exercise"))
         item.connect('activate', self.on_add_link)
         menu.append(item)
+        item = gtk.MenuItem(_("Add link by searching for exercises"))
+        item.connect('activate', self.on_add_link_by_search)
+        menu.append(item)
         menu.show_all()
         menu.popup(None, None, None, event.button, event.time)
     def on_remove(self, btn, event):
         self.m_parent.remove_section(self)
+    def on_add_link_by_search(self, btn):
+        dlg = SelectLessonfileBySearchDialog()
+        while True:
+            ret = dlg.run()
+            if ret == gtk.RESPONSE_OK:
+                self._add_filenames([os.path.abspath(lessonfile.uri_expand(dlg.m_filename))])
+            else:
+                break
+        dlg.destroy()
     def on_add_link(self, btn):
         if editor_of(self).m_filename:
             open_dir = os.path.split(editor_of(self).m_filename)[0]
@@ -288,23 +311,25 @@ class Section(gtk.VBox):
                 break
             else:
                 assert ret == gtk.RESPONSE_OK
-                for filename in dlg.get_filenames():
-                    fn = gu.decode_filename(filename)
-                    assert os.path.isabs(fn)
-                    # If the file name is a file in a subdirectory below
-                    # lessonfile.exercises_dir in the current working directory,
-                    # then the file is a standard lesson file, and it will be
-                    # converted to a uri scheme with:
-                    fn = lessonfile.mk_uri(fn)
-                    # Small test to check that the file actually is a lesson file.
-                    try:
-                        lessonfile.infocache.get(fn, 'title')
-                    except lessonfile.infocache.FileNotLessonfile:
-                        continue
-                    self.m_model.append(fn)
-                    self.g_link_box.pack_start(self.create_linkrow(fn), False)
+                self._add_filenames(dlg.get_filenames())
                 break
         dlg.destroy()
+    def _add_filenames(self, filenames):
+        for filename in filenames:
+            fn = gu.decode_filename(filename)
+            assert os.path.isabs(fn)
+            # If the file name is a file in a subdirectory below
+            # lessonfile.exercises_dir in the current working directory,
+            # then the file is a standard lesson file, and it will be
+            # converted to a uri scheme with:
+            fn = lessonfile.mk_uri(fn)
+            # Small test to check that the file actually is a lesson file.
+            try:
+                lessonfile.infocache.get(fn, 'title')
+            except lessonfile.infocache.FileNotLessonfile:
+                continue
+            self.m_model.append(fn)
+            self.g_link_box.pack_start(self.create_linkrow(fn), False)
     def on_add_link_to_new_page(self, menuitem):
         page = pd.Page(_("Untitled%s") % "", [pd.Column()])
         self.m_model.append(page)
@@ -354,11 +379,11 @@ class Section(gtk.VBox):
             item.set_sensitive(bool(not isinstance(linked, basestring)))
             m.append(item)
             item = gtk.ImageMenuItem(gtk.STOCK_GO_UP)
-            item.connect('activate', self.on_move_up, idx)
+            item.connect('activate', self.on_move_link_up, idx)
             item.set_sensitive(bool(idx > 0))
             m.append(item)
             item = gtk.ImageMenuItem(gtk.STOCK_GO_DOWN)
-            item.connect('activate', self.on_move_down, idx)
+            item.connect('activate', self.on_move_link_down, idx)
             item.set_sensitive(bool(idx < len(self.m_model) - 1))
             m.append(item)
             item = gtk.ImageMenuItem(gtk.STOCK_EDIT)
@@ -433,14 +458,14 @@ class Section(gtk.VBox):
             row = self.create_linkrow(mobj)
             self.g_link_box.pack_start(row)
             self.g_link_box.reorder_child(row, idx)
-    def on_move_up(self, btn, idx):
+    def on_move_link_up(self, btn, idx):
         """
         Move the link one row up.
         """
         assert idx > 0
         self.m_model[idx], self.m_model[idx - 1] = self.m_model[idx - 1], self.m_model[idx]
         self.g_link_box.reorder_child(self.g_link_box.get_children()[idx], idx - 1)
-    def on_move_down(self, btn, idx):
+    def on_move_link_down(self, btn, idx=None):
         """
         Move the link one row down.
         """
@@ -490,14 +515,14 @@ class Column(gtk.VBox):
         gui_section = Section(section, self)
         self.g_section_box.pack_start(gui_section, False)
         gui_section.show_all()
-    def move_section_down(self, section):
+    def move_section_down(self, widget, section):
         idx = self.g_section_box.get_children().index(section)
         if idx < len(self.g_section_box.get_children()) - 1:
             self.g_section_box.reorder_child(section, idx + 1)
             self.m_model[idx], self.m_model[idx + 1] \
                     = self.m_model[idx + 1], self.m_model[idx]
             self.m_parent.update_buttons()
-    def move_section_up(self, section):
+    def move_section_up(self, widget, section):
         idx = self.g_section_box.get_children().index(section)
         if idx > 0:
             self.g_section_box.reorder_child(section, idx - 1)
@@ -605,7 +630,7 @@ class Clipboard(list):
         list.append(self, obj)
         self.update_buttons()
     def register_paste_button(self, button, accepts_types):
-        button.set_sensitive(bool(self) and isinstance(self[-1], types))
+        button.set_sensitive(bool(self) and isinstance(self[-1], accepts_types))
         self.m_paste_buttons.append((button, accepts_types))
     def update_buttons(self):
         for button, types in self.m_paste_buttons:
@@ -618,7 +643,7 @@ class Editor(gtk.Window, gu.EditorDialogBase):
     clipboard = Clipboard()
     def __init__(self, filename=None):
         gtk.Window.__init__(self)
-        logging.debug("fpeditor.Editor.__init__(%s)" % filename)
+        logging.debug("fpeditor.Editor.__init__(%s)", filename)
         gu.EditorDialogBase.__init__(self, filename)
         self.set_default_size(800, 600)
         self.g_main_box = gtk.VBox()
@@ -653,7 +678,7 @@ class Editor(gtk.Window, gu.EditorDialogBase):
         self.g_fptitle.set_text(self.m_model.m_name)
         self.g_fptitle.connect('changed', self.on_frontpage_title_changed)
     def __del__(self):
-        logging.debug("fpeditor.Editor.__del__, filename=" % self.m_filename)
+        logging.debug("fpeditor.Editor.__del__, filename=%s", self.m_filename)
     def add_page(self, page):
         """
         Add and show the page.
@@ -712,9 +737,10 @@ class Editor(gtk.Window, gu.EditorDialogBase):
         Destroy the window with the id 'windowid' and all subwindows.
         """
         def do_del(wid):
-            for key in [k for k in self.m_page_mapping.keys()
-                    if id(parent_page(self.m_page_mapping[k]).m_model) == wid]:
-                do_del(key)
+            for key in self.m_page_mapping:
+                parent = parent_page(self.m_page_mapping[key])
+                if id(parent) == wid:
+                    do_del(key)
             editor_of(self).m_page_mapping[wid].destroy()
             del editor_of(self).m_page_mapping[wid]
         do_del(window_id)
@@ -736,11 +762,11 @@ class Editor(gtk.Window, gu.EditorDialogBase):
         assert self.m_model == None
         self.m_model = pd.load_tree(filename, C_locale=True)
         self.m_filename = filename
-        # 
+        #
         if not os.path.isabs(filename):
             if not os.access(filename, os.W_OK):
                 m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO,
-                    gtk.BUTTONS_CLOSE, _("The default learning tree is write protected in your install. This is normal. If you want to edit a learning tree, you have to select one of the trees stored in .solfege/learningtrees in your home directory."))
+                    gtk.BUTTONS_CLOSE, _("The front page file is write protected in your install. This is normal. If you want to edit a front page file, you have to select one of the files stored in .solfege/exercises/*/ in your home directory."))
                 m.run()
                 m.destroy()
         self.set_not_modified()
@@ -773,7 +799,7 @@ class Editor(gtk.Window, gu.EditorDialogBase):
         self.set_not_modified()
         # We do test for solfege.win since it is not available during testing
         if getattr(solfege, 'win', None):
-            solfege.win.on_frontpage_changed()
+            solfege.win.load_frontpage()
     def on_show_help(self, *w):
         return
     def get_save_as_dialog(self):
