@@ -20,8 +20,8 @@ import gtk
 
 from solfege import cfg
 from solfege import gu
+from solfege import mpd
 from solfege import soundcard
-from solfege import utils
 
 MAX_VOLUME = 127.0
 class MidiInstrumentMenu(gtk.Menu):
@@ -79,7 +79,11 @@ class nInstrumentSelector(gtk.VBox, cfg.ConfigUtils):
         self.m_instrument = instrument
         self.play_selected_instrument()
     def play_selected_instrument(self, _o=None):
-        utils.play_note(4, 60)
+        t = mpd.Track()
+        t.set_patch(self.m_instrument)
+        t.set_volume(self.get_int('%s_volume' % self.m_name))
+        t.note(4, 60)
+        soundcard.synth.play_track(t)
     def show(self):
         self.show_all()
 
