@@ -78,13 +78,11 @@ class SplashWin(gtk.Window):
 
 from solfege.configwindow import ConfigWindow
 from solfege.profilemanager import ChangeProfileDialog
-from solfege.mpd.musicdisplayer import MusicDisplayer
 from solfege import gu
 from solfege import cfg
+from solfege import mpd
 from solfege import stock
 from solfege import lessonfile
-from solfege import lessonfilegui
-from solfege import abstract
 from solfege import download_pyalsa
 from solfege import statistics
 
@@ -99,7 +97,7 @@ class MusicViewerWindow(gtk.Dialog):
     def __init__(self):
         gtk.Dialog.__init__(self)
         self.set_default_size(500, 300)
-        self.g_music_displayer = MusicDisplayer()
+        self.g_music_displayer = mpd.MusicDisplayer()
         self.vbox.pack_start(self.g_music_displayer)
         b = gu.bButton(self.action_area, _("Close"), solfege.win.close_musicviewer)
         b.grab_focus()
@@ -391,11 +389,11 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
                 gtk.main_iteration(0)
     def show_path_info(self, w):
         if not self.g_path_info_dlg:
-            self.g_path_info_dlg = gtk.Dialog(_("File locations"), self,
+            self.g_path_info_dlg = gtk.Dialog(_("_File locations").replace("_", ""), self,
                 buttons=(gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
             vbox = gu.hig_dlg_vbox()
             self.g_path_info_dlg.vbox.pack_start(vbox)
-            box1, box2 = gu.hig_category_vbox(_("File locations"))
+            box1, box2 = gu.hig_category_vbox(_("_File locations").replace("_", ""))
             vbox.pack_start(box1)
             sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
             # statistics.sqlite
@@ -450,7 +448,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         self.g_about_window.destroy()
     def do_tree_editor(self, *v):
         """
-        Open a learning tree editor editing the current front page.
+        Open a front page editor editing the current front page.
         """
         fpeditor.Editor.edit_file(self.get_string("app/frontpage"))
     def post_constructor(self):
