@@ -36,7 +36,7 @@ from solfege.mpd.rat import Rat
 class Duration:
     class BadStringException(Exception):
         pass
-    tre = re.compile("(\d+)(.*)")
+    tre = re.compile("^(\d+)(\.*)$")
     def __init__(self, nh, dots, tuplet=Rat(1, 1)):
         """
         nh   - the type of note: 1 2 4 8 16 32 etc
@@ -51,17 +51,7 @@ class Duration:
         m = Duration.tre.match(string)
         if not m:
             raise Duration.BadStringException(string)
-        if m.groups()[0].isdigit():
-            num = int(m.groups()[0])
-        else:
-            num == 0
-        if m.groups()[1] in (u'', u'.', u'..', u'...', u'....'):
-            dots = len(m.groups()[1])
-        else:
-            dots = None
-        if not m or not m.groups()[0].isdigit() or dots is None:
-            raise Duration.BadStringException(string)
-        return Duration(num, dots)
+        return Duration(int(m.groups()[0]),  len(m.groups()[1]))
     def __cmp__(self, B):
         """
         >>> A=Duration(4, 1, Rat(1, 1))
@@ -88,6 +78,18 @@ class Duration:
         if self.m_dots > 1:
             d = d + Rat(1, self.m_nh * 4)
         return d * self.m_tuplet
+    @staticmethod
+    def new_from_rat(rat):
+        d = Duration(1, 0)
+        while d.get_rat_value() > rat:
+            d.m_nh *= 2
+        # FIXME: how many is the max number of dots? Where to define this?
+        while d.get_rat_value() < rat and d.m_dots < 7:
+            d.m_dots += 1
+        if d.get_rat_value() != rat:
+            d.m_tuplet = rat / d.get_rat_value()
+        assert d.get_rat_value() == rat
+        return d
     def clone(self):
         return Duration(self.m_nh, self.m_dots, self.m_tuplet.clone())
     def __str__(self):
