@@ -18,8 +18,8 @@ class TestClef(unittest.TestCase):
         c = Clef("violin_8")
         self.assertEquals(c.m_octaviation, -7)
     def test_constructor_unknown_clef(self):
-        self.assertRaises(UnknownClefException, lambda : Clef("not a clefname"))
-        self.assertRaises(UnknownClefException, lambda : Clef("violin _ 8"))
+        self.assertRaises(UnknownClefException, Clef, "not a clefname")
+        self.assertRaises(UnknownClefException, Clef, "violin _ 8")
     def test_octaviation(self):
         self.assertEquals(Clef("violin").steps_to_ylinepos(0), 13)
         self.assertEquals(Clef("violin_8").steps_to_ylinepos(0), 13 - 7)
@@ -171,6 +171,12 @@ class TestMpdParser(unittest.TestCase):
     def test_partial_bar(self):
         s = r"\partial 4\staff\relative c'{ c d e }"
         score = parse_to_score_object(s)
+    def test_bar_full(self):
+        try:
+            p = mpd.parser.parse_to_score_object(r"\staff{ c2. c }")
+        except mpd.MpdException, e:
+            self.assertEquals((e.m_lineno, e.m_linepos1, e.m_linepos2),
+                              (0, 12, 13))
     def test_times(self):
         t = mpd.music_to_tracklist(r"\staff{ \times 2/3{c8 d e} }")
         self.assertEquals(t[0].str_repr(),
@@ -192,14 +198,14 @@ class TestLexer(unittest.TestCase):
         t, m = l.next()
         self.assertEquals(t, mpd.lexer.Lexer.NOTE)
         self.assertEquals(m.m_duration, mpd.duration.Duration(4, 1))
-        self.assertRaises(mpd.lexer.LexerError, lambda : l.next())
+        self.assertRaises(mpd.lexer.LexerError, l.next)
     def test_rest_dotting(self):
         l = mpd.lexer.Lexer("c4 r4. r.")
         self.assertEquals(l.next()[1].m_duration, mpd.duration.Duration(4, 0))
         t, m = l.next()
         self.assertEquals(t, mpd.lexer.Lexer.REST)
         self.assertEquals(m.m_duration, mpd.duration.Duration(4, 1))
-        self.assertRaises(mpd.lexer.LexerError, lambda : l.next())
+        self.assertRaises(mpd.lexer.LexerError, l.next)
     def test_inherited_time_dotting(self):
         l = mpd.lexer.Lexer("r4.. c")
         t, m = l.next()
@@ -236,22 +242,24 @@ class TestLexer(unittest.TestCase):
                 r"c \tupletDown d \tupletBoth e \tupletUp f",
                 r"< c4 e g >",
                 r"[ c'8 e ]",
+                r"\partial 8 c8",
                 ):
             self.assertEquals(music, mpd.lexer.Lexer.to_string(list(mpd.lexer.Lexer(music))))
     def test_set_first_pitch_ok(self):
         fis = mpd.MusicalPitch.new_from_notename("fis")
         for s, n in (
             ("c d e", "fis d e"),
-            ("<c'' e>", "< fis e>"),
+            ("<c'' e>", "<fis e>"),
             ("< c'' e>", "< fis e>"),
-            (" c,,16", "fis16"),
-            (" \n c d e", "fis d e"),
+            (" c,,16", " fis16"),
+            (" \n c d e", " \n fis d e"),
             (r"\clef bass c d e", r"\clef bass fis d e"),
             (r"\clef violin \time 3/8 g", r"\clef violin \time 3/8 fis"),
             (r'\clef "violin_8" d', r'\clef "violin_8" fis'),
-            ("\\key g \\major \\time 2/4\n d'8 | [g g]", 
-             "\\key g \\major \\time 2/4 fis8 | [g g]"),
-            ("\nc", "fis"),
+            ("\\key g \\major \\time 2/4\n d'8 | [g g]",
+             "\\key g \\major \\time 2/4\n fis8 | [g g]"),
+            ("\nc", "\nfis"),
+            ("\n\\time 3/4\nc d e", "\n\\time 3/4\nfis d e"),
             ("", ""),
             ):
             lex = mpd.lexer.Lexer(s)
